@@ -1,6 +1,10 @@
 import os
 import sys
+import warnings
+import traceback
 
+warnings.simplefilter('ignore', DeprecationWarning)
+#warnings.simplefilter('ignore', ImportWarning)
 
 modules = [
     "gtkhtml2",
@@ -30,7 +34,8 @@ for item in modules:
         if ex.args[0].startswith("No module named"):
             print "not found"
         else:
-            raise
+            traceback.print_exc()
+            print "NOT ok"
     else:
         print "ok."
 
